-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ --
--
-- Purpose: Adds a fertilization layer when cultivating the green chopped bits of beets.
-- 
-- Authors: Timmiej93
--
-- Copyright (c) Timmiej93, 2018
-- For more information on copyright for this mod, please check the readme file on Github
--
-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ --

ChoppedRadish = {}

function ChoppedRadish:loadMap(name)
	Utils.updateCultivatorArea = Utils.overwrittenFunction(Utils.updateCultivatorArea, ChoppedRadish.updateCultivatorArea)
	Utils.updatePloughArea = Utils.overwrittenFunction(Utils.updatePloughArea, ChoppedRadish.updatePloughArea)
	Utils.updateDirectSowingArea = Utils.overwrittenFunction(Utils.updateDirectSowingArea, ChoppedRadish.updateDirectSowingArea)
end

function ChoppedRadish.updateCultivatorArea(startWorldX, superFunc, startWorldZ, widthWorldX, widthWorldZ, heightWorldX, heightWorldZ, forced, commonForced, angle)
    ChoppedRadish.processChoppedRadishArea(startWorldX, startWorldZ, widthWorldX, widthWorldZ, heightWorldX, heightWorldZ)
	local realArea, area = superFunc(startWorldX, startWorldZ, widthWorldX, widthWorldZ, heightWorldX, heightWorldZ, forced, commonForced, angle)
	return realArea, area
end

function ChoppedRadish.updatePloughArea(startWorldX, superFunc, startWorldZ, widthWorldX, widthWorldZ, heightWorldX, heightWorldZ, forced, commonForced, angle)
	ChoppedRadish.processChoppedRadishArea(startWorldX, startWorldZ, widthWorldX, widthWorldZ, heightWorldX, heightWorldZ)
	local realArea, area = superFunc(startWorldX, startWorldZ, widthWorldX, widthWorldZ, heightWorldX, heightWorldZ, forced, commonForced, angle)
	return realArea, area
end

function ChoppedRadish.updateDirectSowingArea(startWorldX, superFunc, startWorldZ, widthWorldX, widthWorldZ, heightWorldX, heightWorldZ, angle, plantValue)
    ChoppedRadish.processChoppedRadishArea(startWorldX, startWorldZ, widthWorldX, widthWorldZ, heightWorldX, heightWorldZ)
	local realArea, area = superFunc(startWorldX, startWorldZ, widthWorldX, widthWorldZ, heightWorldX, heightWorldZ, angle, plantValue)
	return realArea, area
end

function ChoppedRadish.processChoppedRadishArea(x0,z0, x1,z1, x2,z2)

    local detailId = g_currentMission.terrainDetailId
    local x,z, widthX,widthZ, heightX,heightZ = Utils.getXZWidthAndHeight(detailId, x0,z0, x1,z1, x2,z2)

    local fruitIdOil = g_currentMission.fruits[FruitUtil.FRUITTYPE_OILSEEDRADISH].id
    local fruitIdBeet = g_currentMission.fruits[FruitUtil.FRUITTYPE_SUGARBEET].id

    -- Increase the fertilization level
    addDensityMaskedParallelogram(
        detailId,
        x,z, widthX,widthZ, heightX,heightZ,
        g_currentMission.sprayLevelFirstChannel, 
        g_currentMission.sprayLevelNumChannels,
        fruitIdBeet, 
        4, 1,
        1
    )

	-- Set visual spray level
	setDensityMaskedParallelogram(
		detailId, 
		x0,z0, widthX,widthZ, heightX,heightZ,
		g_currentMission.sprayFirstChannel,
		g_currentMission.sprayNumChannels,
		fruitIdBeet,
		4, 1,
		1
	)
end

function ChoppedRadish:update(dt)end
function ChoppedRadish:deleteMap() end
function ChoppedRadish:keyEvent(unicode, sym, modifier, isDown) end
function ChoppedRadish:mouseEvent(posX, posY, isDown, isUp, button) end
function ChoppedRadish:draw() end

addModEventListener(ChoppedRadish)
